@@ -1,11 +1,13 @@
 # -*- coding: utf-8 -*-
 """These test the utils.py functions."""
 
+from typing import Optional, Tuple, Union
+
 import pytest
 from hypothesis import given
 from hypothesis.strategies import floats, integers
-from natsort.ns_enum import ns
-from natsort.utils import parse_number_or_none_factory
+from natsort.ns_enum import NSType, ns
+from natsort.utils import NumTransformer, parse_number_or_none_factory
 
 
 @pytest.mark.usefixtures("with_locale_en_us")
@@ -19,7 +21,9 @@ from natsort.utils import parse_number_or_none_factory
     ],
 )
 @given(x=floats(allow_nan=False) | integers())
-def test_parse_number_factory_makes_function_that_returns_tuple(x, alg, example_func):
+def test_parse_number_factory_makes_function_that_returns_tuple(
+    x: Union[float, int], alg: NSType, example_func: NumTransformer
+) -> None:
     parse_number_func = parse_number_or_none_factory(alg, "", "xx")
     assert parse_number_func(x) == example_func(x)
 
@@ -34,6 +38,8 @@ def test_parse_number_factory_makes_function_that_returns_tuple(x, alg, example_
         (ns.NANLAST, None, ("", float("+inf"))),  # NANLAST makes it +infinity
     ],
 )
-def test_parse_number_factory_treats_nan_and_none_special(alg, x, result):
+def test_parse_number_factory_treats_nan_and_none_special(
+    alg: NSType, x: Optional[Union[float, int]], result: Tuple[str, Union[float, int]]
+) -> None:
     parse_number_func = parse_number_or_none_factory(alg, "", "xx")
     assert parse_number_func(x) == result
